@@ -16,6 +16,7 @@ from allauth.account.internal.flows.login import (
     record_authentication,
 )
 from allauth.account.internal.flows.signup import send_unknown_account_mail
+from allauth.account.internal.stagekit import clear_login, stash_login
 from allauth.account.models import Login
 
 
@@ -25,7 +26,7 @@ LOGIN_CODE_STATE_KEY = "login_code"
 def request_login_code(
     request: HttpRequest, email: str, login: Optional[Login] = None
 ) -> None:
-    from allauth.account.utils import filter_users_by_email, stash_login
+    from allauth.account.utils import filter_users_by_email
 
     initiated_by_user = login is None
     adapter = get_adapter()
@@ -59,14 +60,14 @@ def request_login_code(
     if initiated_by_user:
         login = Login(user=user, email=email)
         login.state["stages"] = {"current": "login_by_code"}
-    assert login
+    assert login  # nosec
     login.state[LOGIN_CODE_STATE_KEY] = pending_login
     if initiated_by_user:
         stash_login(request, login)
 
 
 def get_pending_login(
-    login: Login, peek: bool = False
+    request, login: Login, peek: bool = False
 ) -> Tuple[Optional[AbstractBaseUser], Optional[Dict[str, Any]]]:
     if peek:
         data = login.state.get(LOGIN_CODE_STATE_KEY)
@@ -76,6 +77,7 @@ def get_pending_login(
         return None, None
     if time.time() - data["at"] >= app_settings.LOGIN_BY_CODE_TIMEOUT:
         login.state.pop(LOGIN_CODE_STATE_KEY, None)
+        clear_login(request)
         return None, None
     user_id_str = data.get("user_id")
     user = None
@@ -86,7 +88,7 @@ def get_pending_login(
 
 
 def record_invalid_attempt(request, login: Login) -> bool:
-    from allauth.account.utils import stash_login, unstash_login
+    from allauth.account.internal.stagekit import stash_login, unstash_login
 
     pending_login = login.state[LOGIN_CODE_STATE_KEY]
     n = pending_login["failed_attempts"]
