@@ -1,3 +1,5 @@
+from typing import Optional
+
 from django.contrib import messages
 from django.http import HttpRequest
 
@@ -30,7 +32,7 @@ def delete_email(request: HttpRequest, email_address: EmailAddress) -> bool:
     else:
         email_address.remove()
         signals.email_removed.send(
-            sender=request.user.__class__,
+            sender=EmailAddress,
             request=request,
             user=request.user,
             email_address=email_address,
@@ -62,12 +64,13 @@ def add_email(request: HttpRequest, form):
         "account/messages/email_confirmation_sent.txt",
         {"email": form.cleaned_data["email"]},
     )
-    signals.email_added.send(
-        sender=request.user.__class__,
-        request=request,
-        user=request.user,
-        email_address=email_address,
-    )
+    if email_address.pk:
+        signals.email_added.send(
+            sender=EmailAddress,
+            request=request,
+            user=request.user,
+            email_address=email_address,
+        )
 
 
 def can_mark_as_primary(email_address: EmailAddress):
@@ -80,8 +83,6 @@ def can_mark_as_primary(email_address: EmailAddress):
 
 
 def mark_as_primary(request: HttpRequest, email_address: EmailAddress):
-    from allauth.account.utils import emit_email_changed
-
     if app_settings.REAUTHENTICATION_REQUIRED:
         raise_if_reauthentication_required(request)
 
@@ -97,7 +98,7 @@ def mark_as_primary(request: HttpRequest, email_address: EmailAddress):
             "account/messages/unverified_primary_email.txt",
         )
     else:
-        assert request.user.is_authenticated
+        assert request.user.is_authenticated  # nosec
         from_email_address = EmailAddress.objects.filter(
             user=request.user, primary=True
         ).first()
@@ -111,3 +112,62 @@ def mark_as_primary(request: HttpRequest, email_address: EmailAddress):
         emit_email_changed(request, from_email_address, email_address)
         success = True
     return success
+
+
+def emit_email_changed(request, from_email_address, to_email_address) -> None:
+    user = to_email_address.user
+    signals.email_changed.send(
+        sender=EmailAddress,
+        request=request,
+        user=user,
+        from_email_address=from_email_address,
+        to_email_address=to_email_address,
+    )
+    if from_email_address:
+        get_adapter().send_notification_mail(
+            "account/email/email_changed",
+            user,
+            context={
+                "from_email": from_email_address.email,
+                "to_email": to_email_address.email,
+            },
+            email=from_email_address.email,
+        )
+
+
+def assess_unique_email(email) -> Optional[bool]:
+    """
+    True -- email is unique
+    False -- email is already in use
+    None -- email is in use, but we should hide that using email verification.
+    """
+    from allauth.account.utils import filter_users_by_email
+
+    if not filter_users_by_email(email):
+        # All good.
+        return True
+    elif not app_settings.PREVENT_ENUMERATION:
+        # Fail right away.
+        return False
+    elif (
+        app_settings.EMAIL_VERIFICATION
+        == app_settings.EmailVerificationMethod.MANDATORY
+    ):
+        # In case of mandatory verification and enumeration prevention,
+        # we can avoid creating a new account with the same (unverified)
+        # email address, because we are going to send an email anyway.
+        assert app_settings.PREVENT_ENUMERATION  # nosec
+        return None
+    elif app_settings.PREVENT_ENUMERATION == "strict":
+        # We're going to be strict on enumeration prevention, and allow for
+        # this email address to pass even though it already exists. In this
+        # scenario, you can signup multiple times using the same email
+        # address resulting in multiple accounts with an unverified email.
+        return True
+    else:
+        assert app_settings.PREVENT_ENUMERATION is True  # nosec
+        # Conflict. We're supposed to prevent enumeration, but we can't
+        # because that means letting the user in, while emails are required
+        # to be unique. In this case, uniqueness takes precedence over
+        # enumeration prevention.
+        return False
