@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from allauth.socialaccount.tests import OAuth2TestsMixin
 from allauth.tests import MockedResponse, TestCase
 
@@ -11,7 +8,10 @@ class BoxOAuth2Tests(OAuth2TestsMixin, TestCase):
     provider_id = BoxOAuth2Provider.id
 
     def get_mocked_response(self):
-        return [MockedResponse(200, """{
+        return [
+            MockedResponse(
+                200,
+                """{
           "type": "user",
           "id": "1185237519",
           "name": "Balls Johnson",
@@ -28,4 +28,9 @@ class BoxOAuth2Tests(OAuth2TestsMixin, TestCase):
           "phone": "123-345-5555",
           "address": "",
           "avatar_url": "https://app.box.com/api/avatar/large/1185237519"
-        }""")]
+        }""",
+            )
+        ]
+
+    def get_expected_to_str(self):
+        return "balls@example.com"
