@@ -1,5 +1,4 @@
-import requests
-
+from allauth.socialaccount.adapter import get_adapter
 from allauth.socialaccount.providers.oauth2.client import (
     OAuth2Client,
     OAuth2Error,
@@ -19,10 +18,14 @@ class DingTalkOAuth2Client(OAuth2Client):
             data["code_verifier"] = pkce_code_verifier
         self._strip_empty_keys(data)
         url = self.access_token_url
-        if self.access_token_method == "GET":
+        if self.access_token_method == "GET":  # nosec
             params = data
             data = None
-        resp = requests.request(self.access_token_method, url, params=params, json=data)
+        resp = (
+            get_adapter()
+            .get_requests_session()
+            .request(self.access_token_method, url, params=params, json=data)
+        )
         resp.raise_for_status()
         access_token = resp.json()
         if not access_token or "accessToken" not in access_token:
