@@ -1,4 +1,7 @@
 from allauth.socialaccount.providers.base import ProviderAccount
+from allauth.socialaccount.providers.doximity.views import (
+    DoximityOAuth2Adapter,
+)
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
 
 
@@ -9,18 +12,15 @@ class DoximityAccount(ProviderAccount):
     def get_avatar_url(self):
         return self.account.extra_data.get("profile_photo")
 
-    def to_str(self):
-        dflt = super(DoximityAccount, self).to_str()
-        return self.account.extra_data.get("full_name", dflt)
-
 
 class DoximityProvider(OAuth2Provider):
     id = "doximity"
     name = "Doximity"
     account_class = DoximityAccount
+    oauth2_adapter_class = DoximityOAuth2Adapter
 
     def extract_uid(self, data):
-        return data[str("id")]  # the Doximity id is long
+        return str(data["id"])  # the Doximity id is long
 
     def extract_common_fields(self, data):
         return dict(
